window.Gleam.initSearch([{"doc":"sunny","title":"sunny","content":"# 🌤️ Sunny\n\nAn [Open-meteo API](https://open-meteo.com/) client written in Gleam. \n\nMakes it easier to get weather forecasts, current and past weather data with different models anywhere you want ! \n\n[![Package Version](https://img.shields.io/hexpm/v/sunny)](https://hex.pm/packages/sunny)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/sunny/)\n\n## Installation\n\nAdd this package to your gleam project (not online yet)\n\n```sh\ngleam add sunny\n```\n\n### Getting the current temperature in a city\n&lt;details open&gt;\n  &lt;summary&gt;Example code&lt;/summary&gt;\n\nHere, the function `send` corresponds to a function that makes a HTTP request.\nFor that, you can use HTTP clients such as `gleam_httpc` or `gleam_fetch`.\n\n```gleam\nimport gleam/dict\nimport gleam/io\nimport gleam/option\n\nimport sunny\nimport sunny/api/forecast\nimport sunny/api/forecast/instant\nimport sunny/api/geocoding\nimport sunny/measurement\n\npub fn main() {\n  let sunny = sunny.new()\n\n  let assert Ok(location) =\n    sunny\n    |&gt; geocoding.get_first_location(\n      geocoding.params(&quot;marseille&quot;)\n      |&gt; geocoding.set_language(geocoding.French),\n    )\n    // Make a HTTP request\n    |&gt; send\n    |&gt; geocoding.get_first_result\n\n  let assert Ok(forecast_result) =\n    sunny\n    |&gt; forecast.get_forecast(\n      forecast.params(geocoding.location_to_position(location))\n      |&gt; forecast.set_current([instant.Temperature2m]),\n    )\n    // Make a HTTP request\n    |&gt; send\n    |&gt; forecast.get_result\n\n  let assert option.Some(current_data) = forecast_result.current\n\n  let assert Ok(temperature) =\n    current_data.data |&gt; dict.get(instant.Temperature2m)\n\n  io.println(\n    location.name\n    &lt;&gt; &quot;&#39;s current temperature is : &quot;\n    &lt;&gt; measurement.to_string(temperature),\n  )\n}\n```\n&lt;/details&gt;\n\nMore examples in the `test/examples` directory\n\nFurther documentation can be found at &lt;https://hexdocs.pm/sunny&gt;.\n\n\n## Contributing\n\nContributions are very welcome ! Make a fork, and once you made the changes you wanted, make a PR.\n\n### Todo \n- Historical forecast API\n- Air quality API\n","url":"index.html"},{"doc":"sunny","title":"sunny","content":"# Getting started\n\nFirst, make sure you added the `sunny` package to your gleam project !\n```\ngleam add sunny\n```\n\nYou will also need a way to make HTTP requests, as this package only returns\nrequests and handles the results. For that, you can use HTTP clients such as \n`gleam_httpc` or `gleam_fetch`.\n\nTo start interacting with the diffent Open-meteo (OM) APIs, you need to create\na new sunny client :\n```gleam\nimport sunny\n\npub fn main() {\n  let sunny = sunny.new()\n}\n```\n&lt;details&gt;\n  &lt;summary&gt;If you have a commercial access to Open-meteo&lt;/summary&gt;\n```gleam\n  let sunny = sunny.new_commercial(&quot;&lt;your_api_key&gt;&quot;)\n```\n&lt;/details&gt;\n\n## Using the APIs\n\nNow you can start using the other APIs :\n- Forecast API : Get a lot a of diverse data on the current and future weather \nconditions anywhere you want.\n- Geocoding API : Get information on a city or town. Useful for getting the coordinates of a place, to then get the forecast there.\n\nMore APIs will be supported in the future.\n\nYou can check the various [examples](examples.html) to get an idea of how to use the APIs.\n","url":"getting_started.html"},{"doc":"sunny","title":"sunny","content":"# Example\n\nHere is a list of the different examples by API.\n\n### Geocoding API\n- [Get the current temperature in a city](examples/city_info.html)\n\n### Forecast API\n- [Get the current temperature at a position](examples/current_temperature.html)\n- [Get the hourly forecast for one day at a position](examples/hourly_forecast.html)\n","url":"examples.html"},{"doc":"sunny","title":"sunny","content":"# Get information on a city or town\n\nThis example uses the Geocoding API. For more information, check the \n`sunny/api/geocoding` module !\n\nHere, the function `send` corresponds to a function that makes a HTTP request.\nFor that, you can use HTTP clients such as `gleam_httpc` or `gleam_fetch`.\n\n```gleam\nimport gleam/int\nimport gleam/io\nimport gleam/option\n\nimport sunny\nimport sunny/api/geocoding\n\npub fn city_info_test() {\n  // Use `new_commercial(&quot;&lt;your_api_key&gt;&quot;)` if you have a commercial Open-meteo\n  // API access.\n  let sunny = sunny.new()\n\n  let assert Ok(location) =\n    sunny\n    |&gt; geocoding.get_request(\n      geocoding.params(&quot;marseille&quot;)\n      // Changing the language can impact the search results.\n      |&gt; geocoding.set_language(geocoding.French),\n    )\n    // Make a HTTP request. \n    |&gt; send\n    // If the location your searching for isn&#39;t the first result, try \n    // `geocoding.get_result`\n    |&gt; geocoding.get_first_result\n\n  // This field can be `option.None` for some places.\n  let assert option.Some(population) = location.population\n\n  io.println(\n    location.name\n    &lt;&gt; &quot;, &quot;\n    &lt;&gt; location.country_code\n    &lt;&gt; &quot; has a population of : &quot;\n    &lt;&gt; int.to_string(population),\n  )\n}\n```","url":"examples/city_info.html"},{"doc":"sunny","title":"sunny","content":"# Get the current temperature at a position\n\nThis example uses the Forecast API. For more information, check the \n`sunny/api/forecast` module !\n\nHere, the function `send` corresponds to a function that makes a HTTP request.\nFor that, you can use HTTP clients such as `gleam_httpc` or `gleam_fetch`.\n\n```gleam\nimport gleam/dict\nimport gleam/io\nimport gleam/option\n\nimport sunny\nimport sunny/api/forecast\nimport sunny/api/forecast/data\nimport sunny/api/forecast/instant\nimport sunny/measurement\nimport sunny/position\n\npub fn current_temperature_test() {\n  // Use `new_commercial(&quot;&lt;your_api_key&gt;&quot;)` if you have a commercial Open-meteo\n  // API access.\n  let sunny = sunny.new()\n\n  // You can get the coordinates of a place using the Geocoding API. See the\n  // `sunny/api/geocoding` module, or the `city_info` example.\n  //\n  // Once you have a `Location`, use `geocoding.location_to_position()` to\n  // convert it to a position.\n  let position = position.Position(43.0, 5.0)\n\n  let assert Ok(forecast_result) =\n    sunny\n    |&gt; forecast.get_request(\n      forecast.params(position)\n      // All available variables are listed in the `sunny/api/forecast/instant` module.\n      // Daily variables are in `sunny/api/forecast/daily`.\n      |&gt; forecast.set_current([instant.Temperature2m]),\n    )\n    // Make a HTTP request.\n    |&gt; send\n    |&gt; forecast.get_result\n\n  let assert option.Some(data.CurrentData(data: data, ..)) =\n    forecast_result.current\n\n  let assert Ok(current_temperature) =\n    data\n    |&gt; dict.get(instant.Temperature2m)\n\n  io.println(\n    &quot;Current temperature : &quot; &lt;&gt; measurement.to_string(current_temperature),\n  )\n}\n```\n\n","url":"examples/current_temperature.html"},{"doc":"sunny","title":"sunny","content":"# Get the hourly forecast for the current day at a position\n\nThis example uses the Forecast API. For more information, check the \n`sunny/api/forecast` module !\n\nHere, the function `send` corresponds to a function that makes a HTTP request.\nFor that, you can use HTTP clients such as `gleam_httpc` or `gleam_fetch`.\n\n```gleam\nimport birl\n\nimport gleam/float\nimport gleam/io\nimport gleam/list\n\nimport sunny\nimport sunny/api/forecast\nimport sunny/api/forecast/data\nimport sunny/api/forecast/instant\nimport sunny/position\nimport sunny/wmo_code\n\npub fn hourly_forecast_test() {\n  // Use `new_commercial(&quot;&lt;your_api_key&gt;&quot;)` if you have a commercial Open-meteo\n  // API access.\n  let sunny = sunny.new()\n\n  // You can get the coordinates of a place using the Geocoding API. See the\n  // `sunny/api/geocoding` module, or the `city_info` example.\n  //\n  // Once you have a `Location`, use `geocoding.location_to_position()` to\n  // convert it to a position.\n  let position = position.Position(43.0, 5.0)\n\n  let assert Ok(forecast_result) =\n    sunny\n    |&gt; forecast.get_request(\n      forecast.params(position)\n      // All available variables are listed in the `sunny/api/forecast/instant`\n      // module.\n      // Daily variables are in `sunny/api/forecast/daily`.\n      |&gt; forecast.set_hourly([instant.WeatherCode])\n      |&gt; forecast.set_forecast_days(1),\n    )\n    // Make a HTTP request.\n    |&gt; send\n    |&gt; forecast.get_result\n\n  let assert Ok(hourly_weather) =\n    forecast_result.hourly\n    |&gt; data.range_to_data_list(instant.WeatherCode)\n\n  hourly_weather\n  |&gt; list.each(fn(timed_data) {\n    io.println(\n      birl.to_time_string(timed_data.time)\n      &lt;&gt; &quot; : &quot;\n      // `wmo_code.to_string` translates the `Int` WMOCode to a human-readable\n      // `String`. \n      &lt;&gt; wmo_code.to_string(float.round(timed_data.data.value)),\n    )\n  })\n}\n```","url":"examples/hourly_forecast.html"},{"doc":"sunny","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Open-meteo client with the default values (you probably won&#39;t\n need anything more).\n \n If you have a commercial Open-meteo API acess, check out `new_commercial`.\nSynonyms:\nsunny.new\nsunny new","url":"sunny.html#new"},{"doc":"sunny","title":"new_commercial","content":"pub fn new_commercial(key: String) -&gt; Client\n Creates a new commercial Open-meteo client with the default values.\n Takes your Open-meteo api key as an argument.\nSynonyms:\nsunny.new_commercial\nsunny new_commercial","url":"sunny.html#new_commercial"},{"doc":"sunny","title":"set_base_url","content":"pub fn set_base_url(client: Client, url: String) -&gt; Client\n Takes a Client and returns a new one with a custom base url.\nSynonyms:\nsunny.set_base_url\nsunny set_base_url","url":"sunny.html#set_base_url"},{"doc":"sunny","title":"sunny","content":"","url":"sunny.html"},{"doc":"sunny/api/forecast/daily","title":"DailyVariable","content":"pub type DailyVariable {\n  MaximumTemperature2m\n  MinimumTemperature2m\n  ApparentTemperatureMax\n  ApparentTemperatureMin\n  PrecipitationSum\n  RainSum\n  ShowersSum\n  SnowfallSum\n  PrecipitationHours\n  PrecipitationProbabilityMax\n  PrecipitationProbabilityMin\n  PrecipitationProbabilityMean\n  WorstWeatherCode\n  SunshineSuration\n  DaylightDuration\n  WindSpeed10mMax\n  WindGusts10mMax\n  WindDirection10mDominant\n}\n Variables that can be obtained at for a specific day (for the `daily` field)\n \n See &lt;https://open-meteo.com/en/docs&gt;\nMaximumTemperature2m\n\n\nMinimumTemperature2m\n\n\nApparentTemperatureMax\n\n\nApparentTemperatureMin\n\n\nPrecipitationSum\n\n\nRainSum\n\n\nShowersSum\n\n\nSnowfallSum\n\n\nPrecipitationHours\n\n\nPrecipitationProbabilityMax\n\n\nPrecipitationProbabilityMin\n\n\nPrecipitationProbabilityMean\n\n\nWorstWeatherCode\n\n\nSunshineSuration\n\n\nDaylightDuration\n\n\nWindSpeed10mMax\n\n\nWindGusts10mMax\n\n\nWindDirection10mDominant\n\n\nSynonyms:\nsunny/api/forecast/daily.DailyVariable\nsunny/api/forecast/daily DailyVariable","url":"sunny/api/forecast/daily.html#DailyVariable"},{"doc":"sunny/api/forecast/daily","title":"all","content":"pub const all: List(DailyVariable)\n A list of all available daily variables.\nSynonyms:\nsunny/api/forecast/daily.all\nsunny/api/forecast/daily all","url":"sunny/api/forecast/daily.html#all"},{"doc":"sunny/api/forecast/daily","title":"sunny/api/forecast/daily","content":"","url":"sunny/api/forecast/daily.html"},{"doc":"sunny/errors","title":"ApiError","content":"pub type ApiError {\n  NoResultsError(msg: String)\n  InvalidArgumentError(msg: String)\n}\n\nNoResultsError(msg: String)\n\n\nInvalidArgumentError(msg: String)\n\n\nSynonyms:\nsunny/errors.ApiError\nsunny/errors ApiError","url":"sunny/errors.html#ApiError"},{"doc":"sunny/errors","title":"DataError","content":"pub type DataError {\n  DataNotFoundError(msg: String)\n}\n\nDataNotFoundError(msg: String)\n\n\nSynonyms:\nsunny/errors.DataError\nsunny/errors DataError","url":"sunny/errors.html#DataError"},{"doc":"sunny/errors","title":"InternalError","content":"pub type InternalError {\n  InternalError(msg: String)\n}\n\nInternalError(msg: String)\n\n\nSynonyms:\nsunny/errors.InternalError\nsunny/errors InternalError","url":"sunny/errors.html#InternalError"},{"doc":"sunny/errors","title":"SunnyError","content":"pub type SunnyError {\n  DecodeError(err: json.DecodeError)\n  ApiError(err: ApiError)\n  DataError(err: DataError)\n  SunnyInternalError(err: InternalError)\n}\n\nDecodeError(err: json.DecodeError)\n Something went wrong with decoding the json obtained with the request.\n\nApiError(err: ApiError)\n An API-related error (e.g. wrong arguments)\n\nDataError(err: DataError)\n Something went wrong while handling data.\n\nSunnyInternalError(err: InternalError)\n Something went wrong internally. If you get this error, please create an\n issue on Github.\n\nSynonyms:\nsunny/errors.SunnyError\nsunny/errors SunnyError","url":"sunny/errors.html#SunnyError"},{"doc":"sunny/errors","title":"sunny/errors","content":" A module with the errors you could get using Sunny.","url":"sunny/errors.html"},{"doc":"sunny/measurement","title":"Measurement","content":"pub type Measurement {\n  Measurement(value: Float, unit: String)\n}\n Represents a physical measurement with a unit \nMeasurement(value: Float, unit: String)\n\n\nSynonyms:\nsunny/measurement.Measurement\nsunny/measurement Measurement","url":"sunny/measurement.html#Measurement"},{"doc":"sunny/measurement","title":"to_string","content":"pub fn to_string(m: Measurement) -&gt; String\n Converts a measurement to a string, displaying its unit.\nSynonyms:\nsunny/measurement.to_string\nsunny/measurement to_string","url":"sunny/measurement.html#to_string"},{"doc":"sunny/measurement","title":"sunny/measurement","content":"","url":"sunny/measurement.html"},{"doc":"sunny/api/forecast/data","title":"CurrentData","content":"pub type CurrentData(data_type) {\n  CurrentData(\n    time: birl.Time,\n    data: dict.Dict(data_type, measurement.Measurement),\n  )\n}\n Data at a specific time.\nCurrentData(\n  time: birl.Time,\n  data: dict.Dict(data_type, measurement.Measurement),\n)\n\n\nSynonyms:\nsunny/api/forecast/data.CurrentData\nsunny/api/forecast/data CurrentData","url":"sunny/api/forecast/data.html#CurrentData"},{"doc":"sunny/api/forecast/data","title":"Data","content":"pub type Data {\n  Data(time: birl.Time, data: measurement.Measurement)\n}\n A measurement at a specific time.\n \n Similar to `CurrentData` but with only one `Measurement`.\nData(time: birl.Time, data: measurement.Measurement)\n\n\nSynonyms:\nsunny/api/forecast/data.Data\nsunny/api/forecast/data Data","url":"sunny/api/forecast/data.html#Data"},{"doc":"sunny/api/forecast/data","title":"TimeRangedData","content":"pub type TimeRangedData(data_type) {\n  TimeRangedData(\n    time: List(birl.Time),\n    data: dict.Dict(data_type, List(measurement.Measurement)),\n  )\n}\n Data over a time range.\nTimeRangedData(\n  time: List(birl.Time),\n  data: dict.Dict(data_type, List(measurement.Measurement)),\n)\n\ntime\n&lt;p&gt;A list of &lt;code&gt;birl.Time&lt;/code&gt;, with each index corresponding to the index of\nthe &lt;code&gt;data&lt;/code&gt; argument.&lt;/p&gt;\n&lt;p&gt;For example, &lt;code&gt;list.first(time)&lt;/code&gt; is the time when the first measurement\nwas taken&lt;/p&gt;\n\nSynonyms:\nsunny/api/forecast/data.TimeRangedData\nsunny/api/forecast/data TimeRangedData","url":"sunny/api/forecast/data.html#TimeRangedData"},{"doc":"sunny/api/forecast/data","title":"range_to_current","content":"pub fn range_to_current(\n  from data: TimeRangedData(a),\n  at time: Time,\n) -&gt; Result(CurrentData(a), SunnyError)\n Converts a `TimeRangedData` to a `CurrentData`, given a specific `time`.\nSynonyms:\nsunny/api/forecast/data.range_to_current\nsunny/api/forecast/data range_to_current","url":"sunny/api/forecast/data.html#range_to_current"},{"doc":"sunny/api/forecast/data","title":"range_to_data_list","content":"pub fn range_to_data_list(\n  from data: TimeRangedData(a),\n  get var: a,\n) -&gt; Result(List(Data), SunnyError)\n Converts a `TimeRangedData` to a list of `Data` for a specific `InstantVariable`\n or `DailyVariable`.\n \n Used in the `hourly_forecast` example.\nSynonyms:\nsunny/api/forecast/data.range_to_data_list\nsunny/api/forecast/data range_to_data_list","url":"sunny/api/forecast/data.html#range_to_data_list"},{"doc":"sunny/api/forecast/data","title":"sunny/api/forecast/data","content":" A module containing useful functions to handle API results.","url":"sunny/api/forecast/data.html"},{"doc":"sunny/api/forecast/instant","title":"InstantVariable","content":"pub type InstantVariable {\n  Temperature2m\n  Temperature80m\n  Temperature120m\n  Temperature180m\n  RelativeHumidity2m\n  DewPoint2m\n  ApparentTemperature\n  PressureMsl\n  SurfacePressure\n  CloudCover\n  CloudCoverLow\n  CloudCoverMid\n  CloudCoverHigh\n  WindSpeed10m\n  WindSpeed80m\n  WindSpeed120m\n  WindSpeed180m\n  WindDirection10m\n  WindDirection80m\n  WindDirection120m\n  WindDirection180m\n  WindGusts10m\n  Precipitation\n  Snowfall\n  PrecipitationProbability\n  Rain\n  Showers\n  WeatherCode\n  SnowDepth\n  FreezingLevelHeight\n  Visibility\n  IsDay\n}\n Variables that can be obtained at a specific time (for `hourly`, `minutely`\n and `current` fields)\n \n See &lt;https://open-meteo.com/en/docs&gt;\nTemperature2m\n\n\nTemperature80m\n\n\nTemperature120m\n\n\nTemperature180m\n\n\nRelativeHumidity2m\n\n\nDewPoint2m\n\n\nApparentTemperature\n\n\nPressureMsl\n\n\nSurfacePressure\n\n\nCloudCover\n\n\nCloudCoverLow\n\n\nCloudCoverMid\n\n\nCloudCoverHigh\n\n\nWindSpeed10m\n\n\nWindSpeed80m\n\n\nWindSpeed120m\n\n\nWindSpeed180m\n\n\nWindDirection10m\n\n\nWindDirection80m\n\n\nWindDirection120m\n\n\nWindDirection180m\n\n\nWindGusts10m\n\n\nPrecipitation\n\n\nSnowfall\n\n\nPrecipitationProbability\n\n\nRain\n\n\nShowers\n\n\nWeatherCode\n\n\nSnowDepth\n\n\nFreezingLevelHeight\n\n\nVisibility\n\n\nIsDay\n\n\nSynonyms:\nsunny/api/forecast/instant.InstantVariable\nsunny/api/forecast/instant InstantVariable","url":"sunny/api/forecast/instant.html#InstantVariable"},{"doc":"sunny/api/forecast/instant","title":"all","content":"pub const all: List(InstantVariable)\n A list of all available instant variables.\nSynonyms:\nsunny/api/forecast/instant.all\nsunny/api/forecast/instant all","url":"sunny/api/forecast/instant.html#all"},{"doc":"sunny/api/forecast/instant","title":"sunny/api/forecast/instant","content":"","url":"sunny/api/forecast/instant.html"},{"doc":"sunny/position","title":"Position","content":"pub type Position {\n  Position(latitude: Float, longitude: Float)\n}\n Describes a position on earth using latitude and longitude.\nPosition(latitude: Float, longitude: Float)\n\n\nSynonyms:\nsunny/position.Position\nsunny/position Position","url":"sunny/position.html#Position"},{"doc":"sunny/position","title":"sunny/position","content":"","url":"sunny/position.html"},{"doc":"sunny/api/forecast","title":"CellSelection","content":"pub type CellSelection {\n  Land\n  Sea\n  Nearest\n}\n\nLand\n\n\nSea\n\n\nNearest\n\n\nSynonyms:\nsunny/api/forecast.CellSelection\nsunny/api/forecast CellSelection","url":"sunny/api/forecast.html#CellSelection"},{"doc":"sunny/api/forecast","title":"ForecastParams","content":"pub type ForecastParams {\n  ForecastParams(\n    position: position.Position,\n    hourly: List(instant.InstantVariable),\n    daily: List(daily.DailyVariable),\n    minutely: List(instant.InstantVariable),\n    current: List(instant.InstantVariable),\n    temperature_unit: TemperatureUnit,\n    wind_speed_unit: WindSpeedUnit,\n    precipitation_unit: PrecipitationUnit,\n    timezone: String,\n    past_days: Int,\n    forecast_days: Int,\n    forecast_hours: option.Option(Int),\n    forecast_minutely_15: option.Option(Int),\n    past_hours: option.Option(Int),\n    past_minutely_15: option.Option(Int),\n    start_date: option.Option(birl.Time),\n    end_date: option.Option(birl.Time),\n    start_hour: option.Option(birl.Time),\n    end_hour: option.Option(birl.Time),\n    start_minutely_15: option.Option(birl.Time),\n    end_minutely_15: option.Option(birl.Time),\n    cell_selection: CellSelection,\n  )\n}\n The different parameters available on the Forecast API.\n \n See &lt;https://open-meteo.com/en/docs&gt; for further reference.\nForecastParams(\n  position: position.Position,\n  hourly: List(instant.InstantVariable),\n  daily: List(daily.DailyVariable),\n  minutely: List(instant.InstantVariable),\n  current: List(instant.InstantVariable),\n  temperature_unit: TemperatureUnit,\n  wind_speed_unit: WindSpeedUnit,\n  precipitation_unit: PrecipitationUnit,\n  timezone: String,\n  past_days: Int,\n  forecast_days: Int,\n  forecast_hours: option.Option(Int),\n  forecast_minutely_15: option.Option(Int),\n  past_hours: option.Option(Int),\n  past_minutely_15: option.Option(Int),\n  start_date: option.Option(birl.Time),\n  end_date: option.Option(birl.Time),\n  start_hour: option.Option(birl.Time),\n  end_hour: option.Option(birl.Time),\n  start_minutely_15: option.Option(birl.Time),\n  end_minutely_15: option.Option(birl.Time),\n  cell_selection: CellSelection,\n)\n\nminutely\n&lt;p&gt;Get data every 15 minutes. Some data can’t be optained every 15\nminutes, so it will be interpolated over the hour (or more if needed)&lt;/p&gt;\n\ntimezone\n&lt;p&gt;Full list here : &lt;a href=&quot;https://en.wikipedia.org/wiki/List_of_tz_database_time_zones#List&quot;&gt;https://en.wikipedia.org/wiki/List_of_tz_database_time_zones#List&lt;/a&gt;&lt;/p&gt;\n&lt;p&gt;You can set &lt;code&gt;timezone&lt;/code&gt; to &lt;code&gt;auto&lt;/code&gt;, and the API will deduce the local\ntimezone from the coordinates.&lt;/p&gt;\n&lt;p&gt;For abbreviations, in my experience only three letter ones work\n(e.g. &lt;code&gt;CEST&lt;/code&gt; returns an error).&lt;/p&gt;\n\npast_days\n&lt;p&gt;Will be clamped between 0 and 92.&lt;/p&gt;\n\nforecast_days\n&lt;p&gt;Will be clamped between 0 and 16.&lt;/p&gt;\n\nforecast_hours\n&lt;p&gt;If &lt;code&gt;forecast_hours&lt;/code&gt; is negative or null, it will be set to &lt;code&gt;option.None&lt;/code&gt;.&lt;/p&gt;\n\nforecast_minutely_15\n&lt;p&gt;If &lt;code&gt;forecast_minutely_15&lt;/code&gt; is negative or null, it will be set to &lt;code&gt;option.None&lt;/code&gt;.&lt;/p&gt;\n\npast_hours\n&lt;p&gt;If &lt;code&gt;past_hours&lt;/code&gt; is negative or null, it will be set to &lt;code&gt;option.None&lt;/code&gt;.&lt;/p&gt;\n\npast_minutely_15\n&lt;p&gt;If &lt;code&gt;past_minutely_15&lt;/code&gt; is negative or null, it will be set to &lt;code&gt;option.None&lt;/code&gt;.&lt;/p&gt;\n\nSynonyms:\nsunny/api/forecast.ForecastParams\nsunny/api/forecast ForecastParams","url":"sunny/api/forecast.html#ForecastParams"},{"doc":"sunny/api/forecast","title":"ForecastResult","content":"pub type ForecastResult {\n  ForecastResult(\n    position: position.Position,\n    elevation: Float,\n    utc_offset_seconds: Int,\n    timezone: String,\n    timezone_abbreviation: String,\n    hourly: data.TimeRangedData(instant.InstantVariable),\n    daily: data.TimeRangedData(daily.DailyVariable),\n    minutely: data.TimeRangedData(instant.InstantVariable),\n    current: option.Option(\n      data.CurrentData(instant.InstantVariable),\n    ),\n  )\n}\n The result of a request to the Forecast API.\nForecastResult(\n  position: position.Position,\n  elevation: Float,\n  utc_offset_seconds: Int,\n  timezone: String,\n  timezone_abbreviation: String,\n  hourly: data.TimeRangedData(instant.InstantVariable),\n  daily: data.TimeRangedData(daily.DailyVariable),\n  minutely: data.TimeRangedData(instant.InstantVariable),\n  current: option.Option(\n    data.CurrentData(instant.InstantVariable),\n  ),\n)\n\n\nSynonyms:\nsunny/api/forecast.ForecastResult\nsunny/api/forecast ForecastResult","url":"sunny/api/forecast.html#ForecastResult"},{"doc":"sunny/api/forecast","title":"PrecipitationUnit","content":"pub type PrecipitationUnit {\n  Millimeters\n  Inches\n}\n\nMillimeters\n\n\nInches\n\n\nSynonyms:\nsunny/api/forecast.PrecipitationUnit\nsunny/api/forecast PrecipitationUnit","url":"sunny/api/forecast.html#PrecipitationUnit"},{"doc":"sunny/api/forecast","title":"TemperatureUnit","content":"pub type TemperatureUnit {\n  Celsius\n  Fahrenheit\n}\n\nCelsius\n\n\nFahrenheit\n\n\nSynonyms:\nsunny/api/forecast.TemperatureUnit\nsunny/api/forecast TemperatureUnit","url":"sunny/api/forecast.html#TemperatureUnit"},{"doc":"sunny/api/forecast","title":"WindSpeedUnit","content":"pub type WindSpeedUnit {\n  KilometersPerHour\n  MetersPerSecond\n  MilesPerHour\n  Knots\n}\n\nKilometersPerHour\n\n\nMetersPerSecond\n\n\nMilesPerHour\n\n\nKnots\n\n\nSynonyms:\nsunny/api/forecast.WindSpeedUnit\nsunny/api/forecast WindSpeedUnit","url":"sunny/api/forecast.html#WindSpeedUnit"},{"doc":"sunny/api/forecast","title":"get_request","content":"pub fn get_request(\n  client: Client,\n  params: ForecastParams,\n) -&gt; Request(String)\n Get a `request.Request(String)` according to the specified `ForecastParams`.\n\n Once you made a request using your favorite HTTP client, pass the `String`\n body to `get_result`.\nSynonyms:\nsunny/api/forecast.get_request\nsunny/api/forecast get_request","url":"sunny/api/forecast.html#get_request"},{"doc":"sunny/api/forecast","title":"get_result","content":"pub fn get_result(\n  response_body: String,\n) -&gt; Result(ForecastResult, SunnyError)\n Get a `ForecastResult` from the body of a HTTP request response.\n \n You can get a request to the Forecast API by using `get_request`.\nSynonyms:\nsunny/api/forecast.get_result\nsunny/api/forecast get_result","url":"sunny/api/forecast.html#get_result"},{"doc":"sunny/api/forecast","title":"params","content":"pub fn params(position: Position) -&gt; ForecastParams\n Creates a new ForecastParams with the default values. Takes the `Position`\n of the place you to get the forecast (see the `sunny/position` module).\n\n Defaults :\n - temperature_unit : Celsius\n - wind_speed_unit : Kilometers per hour\n - precipitation_unit : Millimeters\n - timezone : GMT\n - past_days : 0\n - forecast_days : 7\n - cell_selection : Land\n These are the same defaults as the Open-Meteo API&#39;s ones. Other parameters\n are set to `option.None` or to an empty `List`.\nSynonyms:\nsunny/api/forecast.params\nsunny/api/forecast params","url":"sunny/api/forecast.html#params"},{"doc":"sunny/api/forecast","title":"set_all_current","content":"pub fn set_all_current(\n  params: ForecastParams,\n  except: List(InstantVariable),\n) -&gt; ForecastParams\n Returns a new `ForecastParams` with all the current variables except the\n ones in the `except` argument.\nSynonyms:\nsunny/api/forecast.set_all_current\nsunny/api/forecast set_all_current","url":"sunny/api/forecast.html#set_all_current"},{"doc":"sunny/api/forecast","title":"set_all_daily","content":"pub fn set_all_daily(\n  params: ForecastParams,\n  except: List(DailyVariable),\n) -&gt; ForecastParams\n Returns a new `ForecastParams` with all the daily variables except the \n ones in the `except` argument\nSynonyms:\nsunny/api/forecast.set_all_daily\nsunny/api/forecast set_all_daily","url":"sunny/api/forecast.html#set_all_daily"},{"doc":"sunny/api/forecast","title":"set_all_hourly","content":"pub fn set_all_hourly(\n  params: ForecastParams,\n  except: List(InstantVariable),\n) -&gt; ForecastParams\n Returns a new `ForecastParams` with all the hourly variables except the\n ones in the `except` argument.\nSynonyms:\nsunny/api/forecast.set_all_hourly\nsunny/api/forecast set_all_hourly","url":"sunny/api/forecast.html#set_all_hourly"},{"doc":"sunny/api/forecast","title":"set_all_minutely","content":"pub fn set_all_minutely(\n  params: ForecastParams,\n  except: List(InstantVariable),\n) -&gt; ForecastParams\n Returns a new `ForecastParams` with all the minutely variables except the\n ones in the `except` argument.\nSynonyms:\nsunny/api/forecast.set_all_minutely\nsunny/api/forecast set_all_minutely","url":"sunny/api/forecast.html#set_all_minutely"},{"doc":"sunny/api/forecast","title":"set_cell_selection","content":"pub fn set_cell_selection(\n  params: ForecastParams,\n  cell_selection: CellSelection,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified cell selection.\nSynonyms:\nsunny/api/forecast.set_cell_selection\nsunny/api/forecast set_cell_selection","url":"sunny/api/forecast.html#set_cell_selection"},{"doc":"sunny/api/forecast","title":"set_current","content":"pub fn set_current(\n  params: ForecastParams,\n  current_list: List(InstantVariable),\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified hourly list\nSynonyms:\nsunny/api/forecast.set_current\nsunny/api/forecast set_current","url":"sunny/api/forecast.html#set_current"},{"doc":"sunny/api/forecast","title":"set_daily","content":"pub fn set_daily(\n  params: ForecastParams,\n  daily_list: List(DailyVariable),\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified daily list\nSynonyms:\nsunny/api/forecast.set_daily\nsunny/api/forecast set_daily","url":"sunny/api/forecast.html#set_daily"},{"doc":"sunny/api/forecast","title":"set_end_date","content":"pub fn set_end_date(\n  params: ForecastParams,\n  end_date: Time,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified end date.\nSynonyms:\nsunny/api/forecast.set_end_date\nsunny/api/forecast set_end_date","url":"sunny/api/forecast.html#set_end_date"},{"doc":"sunny/api/forecast","title":"set_end_hour","content":"pub fn set_end_hour(\n  params: ForecastParams,\n  end_hour: Time,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified end hour.\nSynonyms:\nsunny/api/forecast.set_end_hour\nsunny/api/forecast set_end_hour","url":"sunny/api/forecast.html#set_end_hour"},{"doc":"sunny/api/forecast","title":"set_end_minutely_15","content":"pub fn set_end_minutely_15(\n  params: ForecastParams,\n  end_minutely_15: Time,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified end minutely 15.\nSynonyms:\nsunny/api/forecast.set_end_minutely_15\nsunny/api/forecast set_end_minutely_15","url":"sunny/api/forecast.html#set_end_minutely_15"},{"doc":"sunny/api/forecast","title":"set_forecast_days","content":"pub fn set_forecast_days(\n  params: ForecastParams,\n  forecast_days: Int,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified forecast days.\n \n `forecast_days` will be clamped between 0 and 16.\nSynonyms:\nsunny/api/forecast.set_forecast_days\nsunny/api/forecast set_forecast_days","url":"sunny/api/forecast.html#set_forecast_days"},{"doc":"sunny/api/forecast","title":"set_forecast_hours","content":"pub fn set_forecast_hours(\n  params: ForecastParams,\n  forecast_hours: Int,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified forecast hours.\n \n If `forecast_hours` is negative or null, it will be set to `option.None`.\nSynonyms:\nsunny/api/forecast.set_forecast_hours\nsunny/api/forecast set_forecast_hours","url":"sunny/api/forecast.html#set_forecast_hours"},{"doc":"sunny/api/forecast","title":"set_forecast_minutely_15","content":"pub fn set_forecast_minutely_15(\n  params: ForecastParams,\n  forecast_minutely_15: Int,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified forecast minutely 15.\n \n If `forecast_minutely_15` is negative or null, it will be set to `option.None`.\nSynonyms:\nsunny/api/forecast.set_forecast_minutely_15\nsunny/api/forecast set_forecast_minutely_15","url":"sunny/api/forecast.html#set_forecast_minutely_15"},{"doc":"sunny/api/forecast","title":"set_hourly","content":"pub fn set_hourly(\n  params: ForecastParams,\n  hourly_list: List(InstantVariable),\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified hourly list.\nSynonyms:\nsunny/api/forecast.set_hourly\nsunny/api/forecast set_hourly","url":"sunny/api/forecast.html#set_hourly"},{"doc":"sunny/api/forecast","title":"set_minutely","content":"pub fn set_minutely(\n  params: ForecastParams,\n  minutely_list: List(InstantVariable),\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified 15-minutely list\nSynonyms:\nsunny/api/forecast.set_minutely\nsunny/api/forecast set_minutely","url":"sunny/api/forecast.html#set_minutely"},{"doc":"sunny/api/forecast","title":"set_past_days","content":"pub fn set_past_days(\n  params: ForecastParams,\n  past_days: Int,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified past days.\n \n `past_days` will be clamped between 0 and 92.\nSynonyms:\nsunny/api/forecast.set_past_days\nsunny/api/forecast set_past_days","url":"sunny/api/forecast.html#set_past_days"},{"doc":"sunny/api/forecast","title":"set_past_hours","content":"pub fn set_past_hours(\n  params: ForecastParams,\n  past_hours: Int,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified past hours.\n \n If `past_hours` is negative or null, it will be set to `option.None`.\nSynonyms:\nsunny/api/forecast.set_past_hours\nsunny/api/forecast set_past_hours","url":"sunny/api/forecast.html#set_past_hours"},{"doc":"sunny/api/forecast","title":"set_past_minutely_15","content":"pub fn set_past_minutely_15(\n  params: ForecastParams,\n  past_minutely_15: Int,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified past minutely 15.\n \n If `past_minutely_15` is negative or null, it will be set to `option.None`.\nSynonyms:\nsunny/api/forecast.set_past_minutely_15\nsunny/api/forecast set_past_minutely_15","url":"sunny/api/forecast.html#set_past_minutely_15"},{"doc":"sunny/api/forecast","title":"set_precipitation_unit","content":"pub fn set_precipitation_unit(\n  params: ForecastParams,\n  unit: PrecipitationUnit,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified temperature unit.\nSynonyms:\nsunny/api/forecast.set_precipitation_unit\nsunny/api/forecast set_precipitation_unit","url":"sunny/api/forecast.html#set_precipitation_unit"},{"doc":"sunny/api/forecast","title":"set_start_date","content":"pub fn set_start_date(\n  params: ForecastParams,\n  start_date: Time,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified start date.\nSynonyms:\nsunny/api/forecast.set_start_date\nsunny/api/forecast set_start_date","url":"sunny/api/forecast.html#set_start_date"},{"doc":"sunny/api/forecast","title":"set_start_hour","content":"pub fn set_start_hour(\n  params: ForecastParams,\n  start_hour: Time,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified start hour.\nSynonyms:\nsunny/api/forecast.set_start_hour\nsunny/api/forecast set_start_hour","url":"sunny/api/forecast.html#set_start_hour"},{"doc":"sunny/api/forecast","title":"set_start_minutely_15","content":"pub fn set_start_minutely_15(\n  params: ForecastParams,\n  start_minutely_15: Time,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified start minutely 15.\nSynonyms:\nsunny/api/forecast.set_start_minutely_15\nsunny/api/forecast set_start_minutely_15","url":"sunny/api/forecast.html#set_start_minutely_15"},{"doc":"sunny/api/forecast","title":"set_temperature_unit","content":"pub fn set_temperature_unit(\n  params: ForecastParams,\n  unit: TemperatureUnit,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified temperature unit.\nSynonyms:\nsunny/api/forecast.set_temperature_unit\nsunny/api/forecast set_temperature_unit","url":"sunny/api/forecast.html#set_temperature_unit"},{"doc":"sunny/api/forecast","title":"set_timezone","content":"pub fn set_timezone(\n  params: ForecastParams,\n  timezone: String,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified timezone.\nSynonyms:\nsunny/api/forecast.set_timezone\nsunny/api/forecast set_timezone","url":"sunny/api/forecast.html#set_timezone"},{"doc":"sunny/api/forecast","title":"set_wind_speed_unit","content":"pub fn set_wind_speed_unit(\n  params: ForecastParams,\n  unit: WindSpeedUnit,\n) -&gt; ForecastParams\n Returns a new ForecastParams with the specified temperature unit.\nSynonyms:\nsunny/api/forecast.set_wind_speed_unit\nsunny/api/forecast set_wind_speed_unit","url":"sunny/api/forecast.html#set_wind_speed_unit"},{"doc":"sunny/api/forecast","title":"sunny/api/forecast","content":" The module for interactiong with the Forecast API. ","url":"sunny/api/forecast.html"},{"doc":"sunny/api/geocoding","title":"GeocodingParams","content":"pub type GeocodingParams {\n  GeocodingParams(name: String, count: Int, language: Language)\n}\n The different parameters needed to make a request to the geocoding API\nGeocodingParams(name: String, count: Int, language: Language)\n\n\nSynonyms:\nsunny/api/geocoding.GeocodingParams\nsunny/api/geocoding GeocodingParams","url":"sunny/api/geocoding.html#GeocodingParams"},{"doc":"sunny/api/geocoding","title":"Language","content":"pub type Language {\n  English\n  German\n  French\n  Spanish\n  Italian\n  Portuguese\n  Russian\n  Turkish\n  Hindi\n}\n Enumeration of the available languages for the geocoding API.\n Changing the language will impact the search results.\nEnglish\n\n\nGerman\n\n\nFrench\n\n\nSpanish\n\n\nItalian\n\n\nPortuguese\n\n\nRussian\n\n\nTurkish\n\n\nHindi\n\n\nSynonyms:\nsunny/api/geocoding.Language\nsunny/api/geocoding Language","url":"sunny/api/geocoding.html#Language"},{"doc":"sunny/api/geocoding","title":"Location","content":"pub type Location {\n  Location(\n    latitude: Float,\n    longitude: Float,\n    id: Int,\n    name: String,\n    elevation: Float,\n    feature_code: String,\n    country_code: String,\n    country_id: Int,\n    population: option.Option(Int),\n    post_codes: option.Option(List(String)),\n    admin1: option.Option(String),\n    admin2: option.Option(String),\n    admin3: option.Option(String),\n    admin4: option.Option(String),\n    admin1_id: option.Option(Int),\n    admin2_id: option.Option(Int),\n    admin3_id: option.Option(Int),\n    admin4_id: option.Option(Int),\n  )\n}\n Represents a location on good old earth. Can be obtained with the geocoding\n API.\n \n See &lt;https://open-meteo.com/en/docs/geocoding-api&gt;\nLocation(\n  latitude: Float,\n  longitude: Float,\n  id: Int,\n  name: String,\n  elevation: Float,\n  feature_code: String,\n  country_code: String,\n  country_id: Int,\n  population: option.Option(Int),\n  post_codes: option.Option(List(String)),\n  admin1: option.Option(String),\n  admin2: option.Option(String),\n  admin3: option.Option(String),\n  admin4: option.Option(String),\n  admin1_id: option.Option(Int),\n  admin2_id: option.Option(Int),\n  admin3_id: option.Option(Int),\n  admin4_id: option.Option(Int),\n)\n\n\nSynonyms:\nsunny/api/geocoding.Location\nsunny/api/geocoding Location","url":"sunny/api/geocoding.html#Location"},{"doc":"sunny/api/geocoding","title":"get_first_result","content":"pub fn get_first_result(\n  response_body: String,\n) -&gt; Result(Location, SunnyError)\n Get the first `Location` from the body of a HTTP request response. If your\n location is not first, you can use `get_result` instead.\n \n You can get a `request.Request` to the Forecast API by using `get_request`.\nSynonyms:\nsunny/api/geocoding.get_first_result\nsunny/api/geocoding get_first_result","url":"sunny/api/geocoding.html#get_first_result"},{"doc":"sunny/api/geocoding","title":"get_request","content":"pub fn get_request(\n  client: Client,\n  params: GeocodingParams,\n) -&gt; Request(String)\n Get a `request.Request(String)` according to the specified `GeocodingParams`.\n\n Once you made a request using your favorite HTTP client, pass the `String`\n body to `get_result`.\nSynonyms:\nsunny/api/geocoding.get_request\nsunny/api/geocoding get_request","url":"sunny/api/geocoding.html#get_request"},{"doc":"sunny/api/geocoding","title":"get_result","content":"pub fn get_result(\n  response_body: String,\n) -&gt; Result(List(Location), SunnyError)\n Get a `List` of `Location` from the body of a HTTP request response. If you\n only want the first search result, you can use `get_first_result`.\n \n You can get a `request.Request` to the Forecast API by using `get_request`.\nSynonyms:\nsunny/api/geocoding.get_result\nsunny/api/geocoding get_result","url":"sunny/api/geocoding.html#get_result"},{"doc":"sunny/api/geocoding","title":"location_to_position","content":"pub fn location_to_position(location: Location) -&gt; Position\n Converts a location to a position.\nSynonyms:\nsunny/api/geocoding.location_to_position\nsunny/api/geocoding location_to_position","url":"sunny/api/geocoding.html#location_to_position"},{"doc":"sunny/api/geocoding","title":"params","content":"pub fn params(name: String) -&gt; GeocodingParams\n Creates a new GeocodingParams with the default parameters. Takes the name \n of the researched location (by name or by postal code).\n\n Defaults : \n - count : 10\n - language : English\n These are the same defaults as the Open-Meteo API&#39;s ones.\nSynonyms:\nsunny/api/geocoding.params\nsunny/api/geocoding params","url":"sunny/api/geocoding.html#params"},{"doc":"sunny/api/geocoding","title":"set_count","content":"pub fn set_count(\n  params: GeocodingParams,\n  count: Int,\n) -&gt; GeocodingParams\n Creates a new GeocodingParams from the one specified, changing its count\n field.\n \n The count will be clamped between 1 and 100.\nSynonyms:\nsunny/api/geocoding.set_count\nsunny/api/geocoding set_count","url":"sunny/api/geocoding.html#set_count"},{"doc":"sunny/api/geocoding","title":"set_language","content":"pub fn set_language(\n  params: GeocodingParams,\n  language: Language,\n) -&gt; GeocodingParams\n Creates a new GeocodingParams from the one specified, changing its language\n field.\nSynonyms:\nsunny/api/geocoding.set_language\nsunny/api/geocoding set_language","url":"sunny/api/geocoding.html#set_language"},{"doc":"sunny/api/geocoding","title":"sunny/api/geocoding","content":" The module for interacting with the Geocoding API. Useful for getting the\n coordinates of a city to then get the weather forecast.","url":"sunny/api/geocoding.html"},{"doc":"sunny/wmo_code","title":"to_string","content":"pub fn to_string(code: Int) -&gt; String\n Translates the `Int` WMOCode to a human-readable\n`String`. \n \n See https://open-meteo.com/en/docs (at the bottom of the page).\nSynonyms:\nsunny/wmo_code.to_string\nsunny/wmo_code to_string","url":"sunny/wmo_code.html#to_string"},{"doc":"sunny/wmo_code","title":"sunny/wmo_code","content":"","url":"sunny/wmo_code.html"}]);